@@ -53,7 +53,7 @@ class PosetElement(Element):
             self.element = element
         self.vertex = vertex
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         r"""
         TESTS::
 
@@ -64,7 +64,7 @@ class PosetElement(Element):
         """
         return hash(self.element)
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         TESTS::
 
@@ -73,7 +73,7 @@ class PosetElement(Element):
         """
         return "%s" % str(self.element)
 
-    def _latex_(self):
+    def _latex_(self) -> str:
         r"""
         Return the latex code of the poset element.
 
