@@ -108,13 +108,13 @@ def get_editable_root() -> tuple[Path, Path] | None:
     """
     if (
         not is_editable_install()
-        or r"/startdir/src/sage" == ""
-        or r"/startdir/src/sage/.mesonpy-v_0n_j0q" == ""
+        or r"/build/sagemath/src/sage" == ""
+        or r"/build/sagemath/src/sage/.mesonpy-9a3h2w42" == ""
     ):
         return None
 
-    src = Path(r"/startdir/src/sage").resolve()
-    build = Path(r"/startdir/src/sage/.mesonpy-v_0n_j0q").resolve()
+    src = Path(r"/build/sagemath/src/sage").resolve()
+    build = Path(r"/build/sagemath/src/sage/.mesonpy-9a3h2w42").resolve()
     if src.is_dir() and build.is_dir():
         return src, build
     return None
