@@ -18,13 +18,9 @@ more details.
 
 Finding a single triangulation and listing all connected
 triangulations is implemented natively in this package. However, for
-more advanced options [TOPCOM]_ needs to be installed. It is available
-as an optional package for Sage, and you can install it with the
-shell command ::
+more advanced options [TOPCOM]_ needs to be installed; see :ref:`spkg_topcom`.
 
-    sage -i topcom
-
-.. note::
+.. NOTE::
 
     TOPCOM and the internal algorithms tend to enumerate
     triangulations in a different order. This is why we always
@@ -65,7 +61,7 @@ A triangulation of it::
     (2, 3, 4)
     sage: list(t)
     [(1, 3, 4), (2, 3, 4)]
-    sage: t.plot(axes=False)                                                            # needs sage.plot
+    sage: t.plot(axes=False)                                                       # needs sage.plot
     Graphics object consisting of 12 graphics primitives
 
 .. PLOT::
@@ -95,7 +91,7 @@ A 3-dimensional point configuration::
     sage: p = [[0,-1,-1], [0,0,1], [0,1,0], [1,-1,-1], [1,0,1], [1,1,0]]
     sage: points = PointConfiguration(p)
     sage: triang = points.triangulate()
-    sage: triang.plot(axes=False)                                                       # needs sage.plot
+    sage: triang.plot(axes=False)                                                 # needs sage.plot
     Graphics3d Object
 
 .. PLOT::
@@ -120,7 +116,7 @@ The standard example of a non-regular triangulation (requires TOPCOM)::
     16
     sage: len(nonregular)
     2
-    sage: nonregular[0].plot(aspect_ratio=1, axes=False)                                # needs sage.plot
+    sage: nonregular[0].plot(aspect_ratio=1, axes=False)                          # needs sage.plot
     Graphics object consisting of 25 graphics primitives
     sage: PointConfiguration.set_engine('internal')   # to make doctests independent of TOPCOM
 
@@ -183,20 +179,18 @@ AUTHORS:
 ########################################################################
 
 import itertools
-
-from sage.structure.unique_representation import UniqueRepresentation
-from sage.misc.cachefunc import cached_method
-from sage.misc.lazy_import import lazy_import
-
-from sage.rings.integer_ring import ZZ
-from sage.rings.rational_field import QQ
-from sage.matrix.constructor import matrix
-from sage.modules.free_module_element import vector
-
 from copy import copy
 import sys
 import pexpect
 
+from sage.features import FeatureNotPresentError
+from sage.features.topcom import TOPCOMExecutable
+from sage.matrix.constructor import matrix
+from sage.misc.cachefunc import cached_method
+from sage.modules.free_module_element import vector
+from sage.rings.integer_ring import ZZ
+from sage.rings.rational_field import QQ
+from sage.structure.unique_representation import UniqueRepresentation
 
 from sage.geometry.triangulation.base import \
     PointConfiguration_base, Point, ConnectedTriangulationsIterator
@@ -217,25 +211,25 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
     The constructor accepts the following arguments:
 
-    - ``points`` -- the points. Technically, any iterable of iterables
+    - ``points`` -- the points; technically, any iterable of iterables
       will do. In particular, a :class:`PointConfiguration` can be passed.
 
-    - ``projective`` -- boolean (default: ``False``). Whether the
+    - ``projective`` -- boolean (default: ``False``); whether the
       point coordinates should be interpreted as projective (``True``)
       or affine (``False``) coordinates. If necessary, points are
       projectivized by setting the last homogeneous coordinate to one
       and/or affine patches are chosen internally.
 
-    - ``connected`` -- boolean (default: ``True``). Whether the
+    - ``connected`` -- boolean (default: ``True``); whether the
       triangulations should be connected to the regular triangulations
       via bistellar flips. These are much easier to compute than all
       triangulations.
 
-    - ``fine`` -- boolean (default: ``False``). Whether the
+    - ``fine`` -- boolean (default: ``False``); whether the
       triangulations must be fine, that is, make use of all points of
-      the configuration.
+      the configuration
 
-    - ``regular`` -- boolean or ``None`` (default: ``None``). Whether
+    - ``regular`` -- boolean or ``None`` (default: ``None``); whether
       the triangulations must be regular. A regular triangulation is
       one that is induced by a piecewise-linear convex support
       function. In other words, the shadows of the faces of a
@@ -247,7 +241,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
       * ``None`` (default): Both kinds of triangulation.
 
-    - ``star`` -- either ``None`` or a point. Whether the
+    - ``star`` -- either ``None`` or a point; whether the
       triangulations must be star. A triangulation is star if all
       maximal simplices contain a common point. The central point can
       be specified by its index (an integer) in the given points or by
@@ -291,7 +285,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
             PointConfiguration._have_TOPCOM_cached = True
             assert out == '{{0,1}}',\
                 'TOPCOM ran but did not produce the correct output!'
-        except pexpect.ExceptionPexpect:
+        except (FeatureNotPresentError, pexpect.ExceptionPexpect):
             PointConfiguration._have_TOPCOM_cached = False
 
         PointConfiguration.set_engine('auto')
@@ -404,7 +398,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         A :class:`~sage.geometry.triangulation.base.Point` if a
         distinguished star central point has been fixed.
-        :class:`ValueError` exception is raised otherwise.
+        :exc:`ValueError` exception is raised otherwise.
 
         EXAMPLES::
 
@@ -589,13 +583,13 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``executable`` -- string. The name of the executable.
+        - ``executable`` -- string; the name of the executable
 
-        - ``input_string`` -- string. Will be piped into the running
-          executable's stdin.
+        - ``input_string`` -- string; will be piped into the running
+          executable's stdin
 
-        - ``verbose`` -- boolean. Whether to print out the TOPCOM
-          interaction.
+        - ``verbose`` -- boolean; whether to print out the TOPCOM
+          interaction
 
         TESTS::
 
@@ -613,7 +607,9 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
             ['{{0,1,2,4},{1,2,3,4}}']
         """
         timeout = 600
-        proc = pexpect.spawn(executable, timeout=timeout)
+        executable_name, *args = executable.split()
+        executable_absname = TOPCOMExecutable(executable_name).absolute_filename()
+        proc = pexpect.spawn(executable_absname, args, timeout=timeout)
         proc.expect(r'Evaluating Commandline Options \.\.\.')
         proc.expect(r'\.\.\. done\.')
         proc.setecho(0)
@@ -691,7 +687,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
     def _TOPCOM_triangulations(self, verbose=True):
         r"""
-        Returns all triangulations satisfying the restrictions imposed.
+        Return all triangulations satisfying the restrictions imposed.
 
         EXAMPLES::
 
@@ -729,13 +725,13 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``verbose`` -- boolean. Whether to print out the TOPCOM
-          interaction.
+        - ``verbose`` -- boolean; whether to print out the TOPCOM
+          interaction
 
         OUTPUT:
 
         A :class:`~sage.geometry.triangulation.element.Triangulation`
-        satisfying all restrictions imposed. This raises a :class:`ValueError`
+        satisfying all restrictions imposed. This raises a :exc:`ValueError`
         if no such triangulation exists.
 
         EXAMPLES::
@@ -771,9 +767,9 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``regular`` -- ``True``, ``False``, or ``None``. Whether to
+        - ``regular`` -- ``True``, ``False``, or ``None``; whether to
           restrict to regular triangulations, irregular
-          triangulations, or lift any restrictions on regularity.
+          triangulations, or lift any restrictions on regularity
 
         OUTPUT:
 
@@ -815,9 +811,9 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``connected`` -- boolean. Whether to restrict to
+        - ``connected`` -- boolean; whether to restrict to
           triangulations that are connected by bistellar flips to the
-          regular triangulations.
+          regular triangulations
 
         OUTPUT:
 
@@ -854,7 +850,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``fine`` -- boolean. Whether to restrict to fine triangulations.
+        - ``fine`` -- boolean; whether to restrict to fine triangulations
 
         OUTPUT:
 
@@ -927,10 +923,10 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
     def triangulations(self, verbose=False):
         r"""
-        Returns all triangulations.
+        Return all triangulations.
 
-        - ``verbose`` -- boolean (default: ``False``). Whether to
-          print out the TOPCOM interaction, if any.
+        - ``verbose`` -- boolean (default: ``False``); whether to
+          print out the TOPCOM interaction, if any
 
         OUTPUT:
 
@@ -1004,8 +1000,8 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``verbose`` -- boolean. Whether to print out the TOPCOM
-          interaction, if any.
+        - ``verbose`` -- boolean; whether to print out the TOPCOM
+          interaction, if any
 
         OUTPUT:
 
@@ -1033,13 +1029,13 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``verbose`` -- boolean. Whether to print out the TOPCOM
-          interaction, if any.
+        - ``verbose`` -- boolean; whether to print out the TOPCOM
+          interaction, if any
 
         OUTPUT:
 
         A :class:`~sage.geometry.triangulation.element.Triangulation`
-        satisfying all restrictions imposed. This raises a :class:`ValueError`
+        satisfying all restrictions imposed. This raises a :exc:`ValueError`
         if no such triangulation exists.
 
         EXAMPLES::
@@ -1131,10 +1127,10 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
             sage: pyramid = PointConfiguration([[1,0,0], [0,1,1], [0,1,-1],
             ....:                               [0,-1,-1], [0,-1,1]])
-            sage: G = pyramid.restricted_automorphism_group()                           # needs sage.graphs sage.groups
-            sage: G == PermutationGroup([[(3,5)], [(2,3),(4,5)], [(2,4)]])              # needs sage.graphs sage.groups
+            sage: G = pyramid.restricted_automorphism_group()                      # needs sage.graphs sage.groups
+            sage: G == PermutationGroup([[(3,5)], [(2,3),(4,5)], [(2,4)]])         # needs sage.graphs sage.groups
             True
-            sage: DihedralGroup(4).is_isomorphic(G)                                     # needs sage.graphs sage.groups
+            sage: DihedralGroup(4).is_isomorphic(G)                                # needs sage.graphs sage.groups
             True
 
         The square with an off-center point in the middle. Note that
@@ -1142,9 +1138,9 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
         `D_4` of the convex hull::
 
             sage: square = PointConfiguration([(3/4,3/4), (1,1), (1,-1), (-1,-1), (-1,1)])
-            sage: square.restricted_automorphism_group()                                # needs sage.graphs sage.groups
+            sage: square.restricted_automorphism_group()                           # needs sage.graphs sage.groups
             Permutation Group with generators [(3,5)]
-            sage: DihedralGroup(1).is_isomorphic(_)                                     # needs sage.graphs sage.groups
+            sage: DihedralGroup(1).is_isomorphic(_)                                # needs sage.graphs sage.groups
             True
         """
         v_list = [ vector(p.projective()) for p in self ]
@@ -1237,8 +1233,8 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``point_idx_list`` -- a list of integers. The indices of
-          points to exclude.
+        - ``point_idx_list`` -- list of integers; the indices of
+          points to exclude
 
         OUTPUT:
 
@@ -1271,8 +1267,8 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``simplex`` (optional argument) -- a simplex from a
-          triangulation T specified as a list of point indices.
+        - ``simplex`` -- (optional argument) a simplex from a
+          triangulation T specified as a list of point indices
 
         OUTPUT:
 
@@ -1297,7 +1293,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
             sage: p.volume()
             2
 
-        .. note::
+        .. NOTE::
 
             We return `n!` * (metric volume of the simplex) to ensure that
             the volume is an integer.  Essentially, this normalizes
@@ -1485,18 +1481,16 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
     def positive_circuits(self, *negative):
         r"""
-        Returns the positive part of circuits with fixed negative part.
+        Return the positive part of circuits with fixed negative part.
 
         A circuit is a pair `(C_+, C_-)`, each consisting of a subset
         (actually, an ordered tuple) of point indices.
 
         INPUT:
 
-        - ``*negative`` -- integer. The indices of points.
+        - ``*negative`` -- integer; the indices of points
 
-        OUTPUT:
-
-        A tuple of all circuits with `C_-` = ``negative``.
+        OUTPUT: a tuple of all circuits with `C_-` = ``negative``
 
         EXAMPLES::
 
@@ -1534,9 +1528,9 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
             sage: pc.bistellar_flips()
             (((<0,1,3>, <0,2,3>), (<0,1,2>, <1,2,3>)),)
             sage: Tpos, Tneg = pc.bistellar_flips()[0]
-            sage: Tpos.plot(axes=False)                                                 # needs sage.plot
+            sage: Tpos.plot(axes=False)                                            # needs sage.plot
             Graphics object consisting of 11 graphics primitives
-            sage: Tneg.plot(axes=False)                                                 # needs sage.plot
+            sage: Tneg.plot(axes=False)                                            # needs sage.plot
             Graphics object consisting of 11 graphics primitives
 
         The 3d analog::
@@ -1551,7 +1545,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
             sage: pc.bistellar_flips()
             (((<0,1,3>, <0,2,3>), (<0,1,2>, <1,2,3>)),)
             sage: Tpos, Tneg = pc.bistellar_flips()[0]
-            sage: Tpos.plot(axes=False)                                                 # needs sage.plot
+            sage: Tpos.plot(axes=False)                                            # needs sage.plot
             Graphics3d Object
         """
         flips = []
@@ -1656,7 +1650,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
     @cached_method
     def distance_affine(self, x, y):
         r"""
-        Returns the distance between two points.
+        Return the distance between two points.
 
         The distance function used in this method is `d_{aff}(x,y)^2`,
         the square of the usual affine distance function
@@ -1667,7 +1661,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``x``, ``y`` -- two points of the point configuration.
+        - ``x``, ``y`` -- two points of the point configuration
 
         OUTPUT:
 
@@ -1691,7 +1685,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
     @cached_method
     def distance_FS(self, x, y):
         r"""
-        Returns the distance between two points.
+        Return the distance between two points.
 
         The distance function used in this method is `1-\cos
         d_{FS}(x,y)^2`, where `d_{FS}` is the Fubini-Study distance of
@@ -1703,7 +1697,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``x``, ``y`` -- two points of the point configuration.
+        - ``x``, ``y`` -- two points of the point configuration
 
         OUTPUT:
 
@@ -1728,11 +1722,11 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
     @cached_method
     def distance(self, x, y):
         """
-        Returns the distance between two points.
+        Return the distance between two points.
 
         INPUT:
 
-        - ``x``, ``y`` -- two points of the point configuration.
+        - ``x``, ``y`` -- two points of the point configuration
 
         OUTPUT:
 
@@ -1764,9 +1758,9 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``points`` -- a list of points.
+        - ``points`` -- list of points
 
-        - ``among`` -- a list of points or ``None`` (default). The set
+        - ``among`` -- list of points or ``None`` (default); the set
           of points from which to pick the farthest one. By default,
           all points of the configuration are considered.
 
@@ -1804,17 +1798,17 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         INPUT:
 
-        - ``large`` -- boolean. Whether to attempt to return a large
-          simplex.
+        - ``large`` -- boolean; whether to attempt to return a large
+          simplex
 
         - ``initial_point`` -- a
           :class:`~sage.geometry.triangulation.base.Point` or ``None``
           (default). A specific point to start with when picking the
           simplex vertices.
 
-        - ``point_order`` -- a list or tuple of (some or all)
+        - ``point_order`` -- list or tuple of (some or all)
           :class:`~sage.geometry.triangulation.base.Point` s or ``None``
-          (default).
+          (default)
 
         OUTPUT:
 
@@ -1911,9 +1905,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
           will be placed in some arbitrary order that attempts to
           produce a small number of simplices.
 
-        OUTPUT:
-
-        A :class:`~sage.geometry.triangulation.triangulation.Triangulation`.
+        OUTPUT: a :class:`~sage.geometry.triangulation.triangulation.Triangulation`
 
         EXAMPLES::
 
@@ -2043,19 +2035,20 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
     pushing_triangulation = placing_triangulation
 
     @cached_method
-    def Gale_transform(self, points=None):
+    def Gale_transform(self, points=None, homogenize=True):
         r"""
         Return the Gale transform of ``self``.
 
         INPUT:
 
-        - ``points`` -- a tuple of points or point indices or ``None``
+        - ``points`` -- tuple of points or point indices or ``None``
           (default). A subset of points for which to compute the Gale
           transform. By default, all points are used.
 
-        OUTPUT:
+        - ``homogenize`` -- boolean (default: ``True``); whether to add a row
+          of 1's before taking the transform.
 
-        A matrix over :meth:`base_ring`.
+        OUTPUT: a matrix over :meth:`base_ring`
 
         EXAMPLES::
 
@@ -2070,6 +2063,50 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
             sage: points = (pc.point(0), pc.point(1), pc.point(3), pc.point(4))
             sage: pc.Gale_transform(points)
             [ 1 -1  1 -1]
+
+        It is possible to take the inverse of the Gale transform, by specifying
+        whether to homogenize or not::
+
+            sage: pc2 = PointConfiguration([[0,0],[3,0],[0,3],[3,3],[1,1]])
+            sage: pc2.Gale_transform(homogenize=False)
+            [ 1  0  0  0  0]
+            [ 0  1  1  0 -3]
+            [ 0  0  0  1 -3]
+            sage: pc2.Gale_transform(homogenize=True)
+            [ 1  1  1  0 -3]
+            [ 0  2  2 -1 -3]
+
+        It might not affect the result (when acyclic)::
+
+            sage: PC = PointConfiguration([[4,0,0],[0,4,0],[0,0,4],[2,1,1],[1,2,1],[1,1,2]])
+            sage: GT = PC.Gale_transform(homogenize=False);GT
+            [ 1  0  0 -3  1  1]
+            [ 0  1  0  1 -3  1]
+            [ 0  0  1  1  1 -3]
+            sage: GT = PC.Gale_transform(homogenize=True);GT
+            [ 1  0  0 -3  1  1]
+            [ 0  1  0  1 -3  1]
+            [ 0  0  1  1  1 -3]
+
+        The following point configuration is totally cyclic (the cone spanned
+        by the vectors is equal to the vector space spanned by the points),
+        hence its Gale dual is acyclic (there is a linear functional that is
+        positive in all the points of the configuration) when not homogenized::
+
+            sage: pc3 = PointConfiguration([[-1, -1, -1], [-1, 0, 0], [0, -1, 0], [0, 0, -1], [1, 0, 0], [0, 0, 1], [0, 1, 0]])
+            sage: g_hom = pc3.Gale_transform(homogenize=True);g_hom
+            [ 1  0  0 -2  1 -1  1]
+            [ 0  1  0 -1  1 -1  0]
+            [ 0  0  1 -1  0 -1  1]
+            sage: g_inhom = pc3.Gale_transform(homogenize=False);g_inhom
+            [1 0 0 0 1 1 1]
+            [0 1 0 0 1 0 0]
+            [0 0 1 0 0 0 1]
+            [0 0 0 1 0 1 0]
+            sage: Polyhedron(rays=g_hom.columns())
+            A 3-dimensional polyhedron in ZZ^3 defined as the convex hull of 1 vertex and 3 lines
+            sage: Polyhedron(rays=g_inhom.columns())
+            A 4-dimensional polyhedron in ZZ^4 defined as the convex hull of 1 vertex and 4 rays
         """
         self._assert_is_affine()
         if points is None:
@@ -2079,9 +2116,120 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
                 points = [ self.point(ZZ(i)) for i in points ]
             except TypeError:
                 pass
-        m = matrix([ (1,) + p.affine() for p in points])
+        if homogenize:
+            m = matrix([(1,) + p.affine() for p in points])
+        else:
+            m = matrix([p.affine() for p in points])
         return m.left_kernel().matrix()
 
+    def deformation_cone(self, collection):
+        r"""
+        Return the deformation cone for the ``collection`` of subconfigurations
+        of ``self``.
+
+        INPUT:
+
+        - ``collection`` -- a collection of subconfigurations of ``self``.
+          Subconfigurations are given as indices
+
+        OUTPUT: a polyhedron. It contains the liftings of the point configuration
+        making the collection a regular (or coherent, or projective, or
+        polytopal) subdivision.
+
+        EXAMPLES::
+
+            sage: PC = PointConfiguration([(-1, -1), (-1, 0), (0, -1), (1, 0), (0, 1)])
+            sage: coll = [(1, 4), (0, 2), (0, 1), (2, 3), (3, 4)]
+            sage: dc = PC.deformation_cone(coll);dc
+            A 5-dimensional polyhedron in QQ^5 defined as the convex hull of 1 vertex, 3 rays, 2 lines
+            sage: dc.rays()
+            (A ray in the direction (1, 0, 1, 0, 0),
+             A ray in the direction (1, 1, 0, 0, 0),
+             A ray in the direction (1, 1, 1, 0, 0))
+            sage: dc.lines()
+            (A line in the direction (1, 0, 1, 0, -1),
+             A line in the direction (1, 1, 0, -1, 0))
+            sage: dc.an_element()
+            (3, 2, 2, 0, 0)
+
+        We add to the interior element the first line and we verify that the
+        given rays are defining rays of the lower hull::
+
+            sage: P = Polyhedron(rays=[(-1, -1, 4), (-1, 0, 3), (0, -1, 2), (1, 0, -1), (0, 1, 0)])
+            sage: P.rays()
+            (A ray in the direction (-1, -1, 4),
+             A ray in the direction (-1, 0, 3),
+             A ray in the direction (0, -1, 2),
+             A ray in the direction (0, 1, 0),
+             A ray in the direction (1, 0, -1))
+
+        Let's verify the mother of all examples explained in Section 7.1.1 of
+        [DLRS2010]_::
+
+            sage: def mother(epsilon=0):
+            ....:     return PointConfiguration([(4-epsilon,epsilon,0),(0,4-epsilon,epsilon),(epsilon,0,4-epsilon),(2,1,1),(1,2,1),(1,1,2)])
+
+            sage: epsilon = 0
+            sage: m = mother(0)
+            sage: m.points()
+            (P(4, 0, 0), P(0, 4, 0), P(0, 0, 4), P(2, 1, 1), P(1, 2, 1), P(1, 1, 2))
+            sage: S1 = [(0,1,4),(0,3,4),(1,2,5),(1,4,5),(0,2,3),(2,3,5)]
+            sage: S2 = [(0,1,3),(1,3,4),(1,2,4),(2,4,5),(0,2,5),(0,3,5)]
+
+        Both subdivisions `S1` and `S2` are not regular::
+
+            sage: mother_dc1 = m.deformation_cone(S1)
+            sage: mother_dc1
+            A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 1 ray, 3 lines
+            sage: mother_dc2 = m.deformation_cone(S2)
+            sage: mother_dc2
+            A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 1 ray, 3 lines
+
+        Notice that they have a ray which provides a degenerate lifting which
+        only provides a coarsening of the subdivision from the lower hull (it
+        has 5 facets, and should have 8)::
+
+            sage: result = Polyhedron([vector(list(m.points()[_])+[mother_dc1.rays()[0][_]]) for _ in range(len(m.points()))])
+            sage: result.f_vector()
+            (1, 6, 9, 5, 1)
+
+        But if we use epsilon to perturb the configuration, suddenly
+        `S1` becomes regular::
+
+            sage: epsilon = 1/2
+            sage: mp = mother(epsilon)
+            sage: mp.points()
+            (P(7/2, 1/2, 0),
+             P(0, 7/2, 1/2),
+             P(1/2, 0, 7/2),
+             P(2, 1, 1),
+             P(1, 2, 1),
+             P(1, 1, 2))
+            sage: mother_dc1 = mp.deformation_cone(S1);mother_dc1
+            A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 3 rays, 3 lines
+            sage: mother_dc2 = mp.deformation_cone(S2);mother_dc2
+            A 3-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 3 lines
+
+        .. SEEALSO::
+
+            :meth:`~sage.schemes.toric.variety.Kaehler_cone`
+
+        REFERENCES:
+
+            For more information, see Section 5.4 of [DLRS2010]_ and Section
+            2.2 of [ACEP2020].
+        """
+        from sage.geometry.polyhedron.constructor import Polyhedron
+        gale = self.Gale_transform(homogenize=False)
+        dual_rays = gale.columns()
+        n = self.n_points()
+        K = None
+        for cone_indices in collection:
+            dual_cone = Polyhedron(rays=[dual_rays[i] for i in range(n) if i not in cone_indices])
+            K = K.intersection(dual_cone) if K is not None else dual_cone
+        preimages = [gale.solve_right(r.vector()) for r in K.rays()]
+        return Polyhedron(lines=matrix(self.points()).transpose().rows(),rays=preimages)
+
     def plot(self, **kwds):
         r"""
         Produce a graphical representation of the point configuration.
